==> cordova-sqlite-react-1.1.5.tgz: package/SqliteFunction/getDataSqlite.ts <==
import { getDataSqliteT } from './../@types/commonType';
import { generateSQLSelect } from '../stringSQL/generateSELECT';

//INFO: Возможно от проверки таблицы можно избавиться отловив ошибку и определив по ней что нет таблицы
export  const getDataSqlite:getDataSqliteT = (connect, nameTable, {where, sql}) => {
  return new Promise((resolve, reject) => {

    connect.transaction(
      (tx) => {      console.dir(`getDataSqlite: >> Проверка таблицы: ${nameTable}`);
        tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${nameTable}'`, [],
          (tx, res) => {
            let isTables = res.rows.item(0) && res.rows.item(0).name === nameTable; 

            if(isTables){      console.dir(`getDataSqlite: >> запрашиваем данные`);
              let { newSQLSelect, arrValuesPayload } = generateSQLSelect(nameTable, { where, sql })
              
              tx.executeSql(newSQLSelect, arrValuesPayload.length ? arrValuesPayload : [], //arrValuesPayload будет если заполнен where
                (tx, res) => { 
                  let value:any[] = [];
                  for (let i = 0; i < res.rows.length; i++) {    value.push(res.rows.item(i))   }
                  resolve({status: true, value, msg: 'Всё что нашлось'});                                      
                },
                (tx, err) => {console.error(err); }//ошибка должна всплыть  
              );
              return;
            }
            resolve({status: false, msg: 'Таблицы нет'});                                        
          },
          (tx, err) => console.error(err)
        ); 
      },
      (error) => { console.log('Ошибка транзакции в getDataSqlite: '); reject({status: false, msg: error}); }, 
      () => { console.log('Успех транзакции getDataSqlite');  }
    )
  })
}


/*-------------------------------------------------------------------------------------------------------------------------------------*/



// export function getDataSqlite(nameTable: string, strSql: string) {



//   return new Promise<{status: boolean, value?:{}[] | [], msg?:string}>((resolve, reject) => {
   

//     if(window.cordova && window.sqlitePlugin){
//       let db = openDbSqlite((process.env.REACT_APP_SQLITE_DB_NAME as string)); 
      
//       db.transaction(
//         (tx) => {
//           console.dir('Начата транзакция getDataSqlite');
//           console.dir(`Шаг 1й. Проверка таблицы ${nameTable}`);
//           tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${nameTable}'`, [],
//             (tx, res) => {
              
//               if(res.rows.item(0) && res.rows.item(0).name === nameTable){    
//                  console.dir('Шаг 2й. Таблица есть, запрашиваем данные');
//                 tx.executeSql(strSql, [], 
//                   (tx, res) => { 
                  
//                       let value:any[] = [];
//                       //сделано так т.к. можем запрашивать не только 1 пользователя 
//                       for (let i = 0; i < res.rows.length; i++) {
//                         value.push(res.rows.item(i))
//                       }
//                       console.log('Всё что нашлось, то и вернём в resolve', value);
//                       resolve({status: true, value, msg: 'Всё что нашлось'});     
                                                     
//                   },
//                   (tx, err) => {console.error(err); }//ошибка должна всплыть  
//                 );

//                 console.groupEnd();
//                 return;
//               }
             
//               console.dir(res.rows);                        
            
//               resolve({status: false, msg: 'Таблицы нет'});                                        
//             },
//             (tx, err) => console.error(err)
//           ); 
//         },
//         (error) => { console.log('Ошибка транзакции в getDataSqlite: '); reject({status: false, msg: error}); }, 
//         () => { console.log('Успех транзакции getDataSqlite');  }
//       ) ;
//       console.groupEnd();
//       return;
//     }
//     reject(new Error('Не установлен плагин cordova || cordova-sqlite-storage'));


//   })
// }

==> cordova-sqlite-react-1.1.8.tgz: package/SqliteFunction/getDataSqlite.ts <==
import { getDataSqliteT } from './../@types/commonType';
import { generateSQLSelect } from '../stringSQL/generateSELECT';

//INFO: Возможно от проверки таблицы можно избавиться отловив ошибку и определив по ней что нет таблицы
export  const getDataSqlite:getDataSqliteT = (connect, nameTable, {where, sql}) => {
  return new Promise((resolve, reject) => {

    connect.transaction(
      (tx) => {      console.dir(`getDataSqlite: >> Проверка таблицы: ${nameTable}`);
        tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${nameTable}'`, [],
          (tx, res) => {
            let isTables = res.rows.item(0) && res.rows.item(0).name === nameTable; 

            if(isTables){      console.dir(`getDataSqlite: >> запрашиваем данные`);
              let { newSQLSelect, arrValuesPayload } = generateSQLSelect(nameTable, { where, sql })
              
              tx.executeSql(newSQLSelect, arrValuesPayload.length ? arrValuesPayload : [], //arrValuesPayload будет если заполнен where
                (tx, res) => { 
                  let values:any[] = [];
                  for (let i = 0; i < res.rows.length; i++) {    values.push(res.rows.item(i))   }
                  if(!values.length){
                    resolve({status: false, values, msg: 'Данных нет в таблице'});  
                  }else{

                    
                    resolve({status: true, values, msg: 'Данные найдены'});                                      
                  }
                },
                (tx, err) => {console.error(err); }//ошибка должна всплыть  
              );
              return;
            }
            resolve({status: false, values: [],  msg: 'Таблицы нет'});                                        
          },
          (tx, err) => console.error(err)
        ); 
      },
      (error) => { console.log('Ошибка транзакции в getDataSqlite: '); reject({status: false, msg: error}); }, 
      () => { console.log('Успех транзакции getDataSqlite');  }
    )
  })
}


/*-------------------------------------------------------------------------------------------------------------------------------------*/



// export function getDataSqlite(nameTable: string, strSql: string) {



//   return new Promise<{status: boolean, value?:{}[] | [], msg?:string}>((resolve, reject) => {
   

//     if(window.cordova && window.sqlitePlugin){
//       let db = openDbSqlite((process.env.REACT_APP_SQLITE_DB_NAME as string)); 
      
//       db.transaction(
//         (tx) => {
//           console.dir('Начата транзакция getDataSqlite');
//           console.dir(`Шаг 1й. Проверка таблицы ${nameTable}`);
//           tx.executeSql(`SELECT name FROM sqlite_master WHERE type='table' AND name='${nameTable}'`, [],
//             (tx, res) => {
              
//               if(res.rows.item(0) && res.rows.item(0).name === nameTable){    
//                  console.dir('Шаг 2й. Таблица есть, запрашиваем данные');
//                 tx.executeSql(strSql, [], 
//                   (tx, res) => { 
                  
//                       let value:any[] = [];
//                       //сделано так т.к. можем запрашивать не только 1 пользователя 
//                       for (let i = 0; i < res.rows.length; i++) {
//                         value.push(res.rows.item(i))
//                       }
//                       console.log('Всё что нашлось, то и вернём в resolve', value);
//                       resolve({status: true, value, msg: 'Всё что нашлось'});     
                                                     
//                   },
//                   (tx, err) => {console.error(err); }//ошибка должна всплыть  
//                 );

//                 console.groupEnd();
//                 return;
//               }
             
//               console.dir(res.rows);                        
            
//               resolve({status: false, msg: 'Таблицы нет'});                                        
//             },
//             (tx, err) => console.error(err)
//           ); 
//         },
//         (error) => { console.log('Ошибка транзакции в getDataSqlite: '); reject({status: false, msg: error}); }, 
//         () => { console.log('Успех транзакции getDataSqlite');  }
//       ) ;
//       console.groupEnd();
//       return;
//     }
//     reject(new Error('Не установлен плагин cordova || cordova-sqlite-storage'));


//   })
// }
